\name{LorHDR-package}
\alias{LorHDR-package}
\alias{LorHDR}
\docType{package}
\title{
Unimodal HDR and ln(OR) pdf, cdf, qf
}
\description{
Computes HDR of a unimodal distribution
Implements the distribution of Lor = ln(OR) for the odds ratio of two independent betas
}
\details{
\tabular{ll}{
Package: \tab LorHDR\cr
Type: \tab Package\cr
Version: \tab 1.0\cr
Date: \tab 2013-03-09\cr
License: \tab What license is it under?\cr
}
HDR(A,"dist",...) computes the 100A percent HD interval, the two tails and the pdf at the endpoints.
dLor(lor,a1,b1,a2,b2) and pLor are pdf and cdf of the distribution of ln(p1/(1-p1)) - ln(p2/(1-p2)) where p1~dbeta(a1,b1) and p2~dbeta(a2,b2)
qLor(p,a1,b1,a2,b2) is the quantile function
}
\author{
George Woodworth

Maintainer: Who to complain to <george-woodworth@uiowa.edu>
}
\references{
Woodworth,G.G., Biostatistics: A Bayesian Introduction, 2nd ed
}
~~ Optionally other standard keywords, one per line, from ~~
~~ file KEYWORDS in the R documentation directory ~~
\keyword{ package }
\seealso{
~~ Optional links to other man pages, e.g. ~~
~~ \code{\link[<pkg>:<pkg>-package]{<pkg>}} ~~
}
\examples{
# binomial sample n=35, x=10 
# Jeffreys prior dbeta(0.5,0.5)
# posterior dbeta(10.5,25.5)
# 95 percent HDR
  HDR(0.95,"beta",shape1=10.5,shape2=25.5)
#              Lower      Upper
# HDR     0.15042783 0.43932522
# Tails   0.01851693 0.03148307
# Density 0.83256148 0.83230022
################################
# Clinical trial 1=Treatment 2=Control
  n1 = 78; x1 = 34
  n2 = 70; x2 = 11
# Jeffreys prior
hdr <-  HDR(.95,"Lor",a1=34.5,b1=44,a2=11.5,b2=69.5); hdr
#              Lower      Upper
# HDR     0.81768816 2.37485746
# Tails   0.02268496 0.02731504
# Density 0.14526703 0.14511605
#
# 95 percent Credible interval for Odds Ratio
  exp(hdr[1,])
#     Lower     Upper 
#  2.265257 10.749481 
#
# Verify content of HDR
  pLor(2.3749,a1=34.5,b1=44,a2=11.5,b2=69.5)-
    pLor(0.8177,a1=34.5,b1=44,a2=11.5,b2=69.5)
# [1] 0.9500046
#
# 95 percent equal tail CI for ln(OR) and OR
  LorCI <- qLor(c(.025,.975),a1=34.5,b1=44,a=11.5,b2=69.5)
  ORCI <- exp(LorCI)
  LorCI; ORCI 
# [1]  0.832987  2.391425
# [1]  2.300181 10.929058

